==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_iot_data/paginator.py <==
"""
Type annotations for iot-data service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iot_data/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_iot_data.client import IoTDataPlaneClient
    from types_boto3_iot_data.paginator import (
        ListRetainedMessagesPaginator,
    )

    session = Session()
    client: IoTDataPlaneClient = session.client("iot-data")

    list_retained_messages_paginator: ListRetainedMessagesPaginator = client.get_paginator("list_retained_messages")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListRetainedMessagesRequestListRetainedMessagesPaginateTypeDef,
    ListRetainedMessagesResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListRetainedMessagesPaginator",)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListRetainedMessagesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data/paginator/ListRetainedMessages.html#IoTDataPlane.Paginator.ListRetainedMessages)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iot_data/paginators/#listretainedmessagespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListRetainedMessagesRequestListRetainedMessagesPaginateTypeDef]
    ) -> _PageIterator[ListRetainedMessagesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data/paginator/ListRetainedMessages.html#IoTDataPlane.Paginator.ListRetainedMessages.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iot_data/paginators/#listretainedmessagespaginator)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_iot_data/paginator.py <==
"""
Type annotations for iot-data service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iot_data/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_iot_data.client import IoTDataPlaneClient
    from types_boto3_iot_data.paginator import (
        ListRetainedMessagesPaginator,
    )

    session = Session()
    client: IoTDataPlaneClient = session.client("iot-data")

    list_retained_messages_paginator: ListRetainedMessagesPaginator = client.get_paginator("list_retained_messages")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListRetainedMessagesRequestPaginateTypeDef,
    ListRetainedMessagesResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListRetainedMessagesPaginator",)


if TYPE_CHECKING:
    _ListRetainedMessagesPaginatorBase = Paginator[ListRetainedMessagesResponseTypeDef]
else:
    _ListRetainedMessagesPaginatorBase = Paginator  # type: ignore[assignment]


class ListRetainedMessagesPaginator(_ListRetainedMessagesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data/paginator/ListRetainedMessages.html#IoTDataPlane.Paginator.ListRetainedMessages)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iot_data/paginators/#listretainedmessagespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListRetainedMessagesRequestPaginateTypeDef]
    ) -> PageIterator[ListRetainedMessagesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data/paginator/ListRetainedMessages.html#IoTDataPlane.Paginator.ListRetainedMessages.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iot_data/paginators/#listretainedmessagespaginator)
        """
